@@ -1,6 +1,6 @@
-/* $Id: terminal-accel-map.c 73 2004-11-29 00:46:37Z bmeurer $ */
+/* $Id: terminal-accel-map.c 25928 2007-07-20 15:43:29Z benny $ */
 /*-
- * Copyright (c) 2004 os-cillation e.K.
+ * Copyright (c) 2004-2007 os-cillation e.K.
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
  *
@@ -25,6 +25,7 @@
 
 #include <terminal/terminal-accel-map.h>
 #include <terminal/terminal-preferences.h>
+#include <terminal/terminal-private.h>
 
 
 
@@ -45,10 +46,6 @@ struct _TerminalAccelMap
 
 
 
-static GObjectClass *parent_class;
-
-
-
 G_DEFINE_TYPE (TerminalAccelMap, terminal_accel_map, G_TYPE_OBJECT);
 
 
@@ -58,8 +55,6 @@ terminal_accel_map_class_init (TerminalAccelMapClass *klass)
 {
   GObjectClass *gobject_class;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = terminal_accel_map_finalize;
 }
@@ -104,7 +99,7 @@ terminal_accel_map_finalize (GObject *object)
   g_signal_handlers_disconnect_by_func (G_OBJECT (map->preferences), G_CALLBACK (terminal_accel_map_notify), map);
   g_object_unref (G_OBJECT (map->preferences));
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  (*G_OBJECT_CLASS (terminal_accel_map_parent_class)->finalize) (object);
 }
 
 
@@ -119,7 +114,7 @@ terminal_accel_map_notify (TerminalPreferences *preferences,
   guint           accelerator_key;
   gchar          *accelerator;
 
-  g_return_if_fail (g_str_has_prefix (pspec->name, "accel-"));
+  _terminal_return_if_fail (g_str_has_prefix (pspec->name, "accel-"));
 
   accelerator_path = g_strconcat ("<Actions>/terminal-window/", pspec->name + 6, NULL);
 
