@@ -1,4 +1,4 @@
-/* $Id: terminal-dialogs.c 24238 2007-01-02 11:42:49Z benny $ */
+/* $Id: terminal-dialogs.c 25928 2007-07-20 15:43:29Z benny $ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>
  *
@@ -28,6 +28,7 @@
 #include <exo/exo.h>
 
 #include <terminal/terminal-dialogs.h>
+#include <terminal/terminal-private.h>
 
 
 
@@ -78,7 +79,11 @@ terminal_dialogs_show_about (GtkWindow *parent)
                          "copyright", "Copyright \302\251 2003-2007 Benedikt Meurer",
                          "license", XFCE_LICENSE_GPL,
                          "logo", logo,
+#if GTK_CHECK_VERSION(2,11,0)
+                         "program-name", PACKAGE_NAME,
+#else
                          "name", PACKAGE_NAME,
+#endif
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
                          "website", "http://terminal.os-cillation.de",
@@ -118,7 +123,7 @@ terminal_dialogs_show_error (gpointer      parent,
   va_list    args;
   gchar     *primary_text;
 
-  g_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
+  _terminal_return_if_fail (parent == NULL || GDK_IS_SCREEN (parent) || GTK_IS_WIDGET (parent));
 
   /* determine the proper parent */
   if (parent == NULL)
